@@ -11,6 +11,7 @@ following:
   Number of elements: 2
   Number of vertices: 4
   Number of nodes: 4
+  Named boundaries [# facets]: left [1], bottom [1], right [1], top [1]
 
 2. Create :class:`~skfem.assembly.CellBasis` or
    :class:`~skfem.assembly.BoundaryFacetBasis` objects.
@@ -46,14 +47,10 @@ array([[0.08333333, 0.04166667, 0.04166667, 0.        ],
 array([0.0162037 , 0.15046296, 0.06712963, 0.09953704])
 
 """
-
-from typing import Union
+import logging
+from typing import Any
 from itertools import product
 
-from numpy import ndarray
-
-from scipy.sparse import csr_matrix
-
 from .basis import (Basis, CellBasis, FacetBasis, BoundaryFacetBasis,
                     InteriorFacetBasis, MortarFacetBasis)
 from .basis import InteriorBasis, ExteriorFacetBasis  # backwards compatibility
@@ -61,19 +58,35 @@ from .dofs import Dofs, DofsView
 from .form import Form, TrilinearForm, BilinearForm, LinearForm, Functional
 
 
+logger = logging.getLogger(__name__)
+
+
+def _sum(blocks):
+    out = sum(blocks)
+    assert not isinstance(out, int)
+    return out.todefault()
+
+
 def asm(form: Form,
-        *args, **kwargs) -> Union[ndarray, csr_matrix]:
+        *args,
+        to=_sum,
+        **kwargs) -> Any:
     """Perform finite element assembly.
 
     A shorthand for :meth:`skfem.assembly.Form.assemble` which, in addition,
     supports assembling multiple bases at once and summing the result.
 
     """
+    assert form.form is not None
+    logger.info("Assembling '{}'.".format(form.form.__name__))
     nargs = [[arg] if not isinstance(arg, list) else arg for arg in args]
-    out = sum(map(lambda bases: form.coo_data(*bases, **kwargs),
-                  product(*nargs)))
-    assert not isinstance(out, int)
-    return out.todefault()
+    retval = to(map(lambda a: form.coo_data(*a[1],
+                                            idx=a[0],
+                                            **kwargs),
+                    zip(product(*(range(len(x)) for x in nargs)),
+                        product(*nargs))))
+    logger.info("Assembling finished.")
+    return retval
 
 
 __all__ = [
