@@ -27,8 +27,8 @@ class BoundaryFacetBasis(AbstractBasis):
                  intorder: Optional[int] = None,
                  quadrature: Optional[Tuple[ndarray, ndarray]] = None,
                  facets: Optional[ndarray] = None,
-                 _side: int = 0,
-                 dofs: Optional[Dofs] = None):
+                 dofs: Optional[Dofs] = None,
+                 _tind: Optional[ndarray] = None):
         """Precomputed global basis on boundary facets.
 
         Parameters
@@ -52,9 +52,10 @@ class BoundaryFacetBasis(AbstractBasis):
             Optional :class:`~skfem.assembly.Dofs` object.
 
         """
-        logger.info("Initializing {}({}, {})".format(type(self).__name__,
-                                                     type(mesh).__name__,
-                                                     type(elem).__name__))
+        typestr = ("{}({}, {})".format(type(self).__name__,
+                                       type(mesh).__name__,
+                                       type(elem).__name__))
+        logger.info("Initializing " + typestr)
         super(BoundaryFacetBasis, self).__init__(mesh,
                                                  elem,
                                                  mapping,
@@ -67,9 +68,15 @@ class BoundaryFacetBasis(AbstractBasis):
         if facets is None:
             self.find = np.nonzero(self.mesh.f2t[1] == -1)[0]
         else:
-            self.find = facets
-        self.tind = self.mesh.f2t[_side, self.find]
-        self._side = _side  # for debugging
+            self.find = self._normalize_facets(facets)
+
+        if len(self.find) == 0:
+            logger.warning("Initializing {} with zero facets.".format(typestr))
+
+        if _tind is None:
+            self.tind = self.mesh.f2t[0, self.find]
+        else:
+            self.tind = _tind
 
         # boundary refdom to global facet
         x = self.mapping.G(self.X, find=self.find)
@@ -207,3 +214,29 @@ class BoundaryFacetBasis(AbstractBasis):
             quadrature=self.quadrature,
             facets=self.find,
         )
+
+    def project(self, interp, facets=None):
+        """Perform :math:`L^2` projection onto the basis on the boundary.
+
+        The values of the interior DOFs remain zero.
+
+        Parameters
+        ----------
+        interp
+            An object of type :class:`~skfem.element.DiscreteField` which is a
+            function (to be projected) evaluated at global quadrature points at
+            the boundary of the domain.  If a function is given, then
+            :class:`~skfem.element.DiscreteField` is created by passing
+            an array of global quadrature point locations to the function.
+        facets
+            Optionally perform the projection on a subset of facets.  The
+            values of the remaining DOFs are zero.
+
+        """
+        from skfem.utils import solve, condense
+
+        M, f = self._projection(interp)
+
+        if facets is not None:
+            return solve(*condense(M, f, I=self.get_dofs(facets=facets)))
+        return solve(*condense(M, f, I=self.get_dofs(facets=self.find)))
