@@ -88,7 +88,7 @@ class COOData:
         )
 
     def toarray(self) -> ndarray:
-        """Return a dense NumPy array."""
+        """Return a dense numpy array."""
         if len(self.shape) == 1:
             return coo_matrix(
                 (self.data, (self.indices[0], np.zeros_like(self.indices[0]))),
@@ -114,7 +114,7 @@ class COOData:
 
         """
         if len(self.shape) == 0:
-            return self.data[0]
+            return np.sum(self.data, axis=0)
         elif len(self.shape) == 1:
             return self.toarray()
         elif len(self.shape) == 2:
