@@ -13,6 +13,7 @@ from .element import Element
 from .element_h1 import ElementH1
 from .element_hdiv import ElementHdiv
 from .element_hcurl import ElementHcurl
+from .element_global import ElementGlobal
 from .element_vector import ElementVector
 from .element_tri import (ElementTriP1, ElementTriP2,  # noqa
                           ElementTriP0, ElementTriRT0, ElementTriMorley,
@@ -24,7 +25,7 @@ from .element_tri import (ElementTriP1, ElementTriP2,  # noqa
                           ElementTriBDM1)
 from .element_quad import (ElementQuad0, ElementQuad1, ElementQuad2,  # noqa
                            ElementQuadS2, ElementQuadP,
-                           ElementQuadBFS, ElementQuad1DG)
+                           ElementQuadBFS, ElementQuadRT0, ElementQuad1DG)
 from .element_tet import (ElementTetP0, ElementTetP1, ElementTetP2,  # noqa
                           ElementTetRT0, ElementTetN0, ElementTetMini,
                           ElementTetCR, ElementTetCCR)
@@ -69,6 +70,7 @@ __all__ = [
     "ElementVectorH1",
     "ElementHdiv",
     "ElementHcurl",
+    "ElementGlobal",
     "ElementDG",
     "ElementComposite",
     "ElementTriP1",
@@ -96,6 +98,7 @@ __all__ = [
     "ElementQuadDG",
     "ElementQuadP",
     "ElementQuadBFS",
+    "ElementQuadRT0",
     "ElementQuad1DG",
     "ElementTetP0",
     "ElementTetP1",
